@@ -75,6 +75,10 @@ gboolean gdm_test_opt (const char *cmd, const char *help, const char *option);
 
 void gdm_close_all_descriptors (int from, int except);
 
+gboolean gdm_is_a_no_password_user (const char *user);
+
+int gdm_open_dev_null (mode_t mode);
+
 #endif /* GDM_MISC_H */
 
 /* EOF */
