@@ -54,7 +54,7 @@ greeter_item_info_free (GreeterItemInfo *info)
 
   for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
     if (info->pixbufs[i])
-      gdk_pixbuf_unref (info->pixbufs[i]);
+      g_object_unref (G_OBJECT (info->pixbufs[i]));
 
   g_free (info->id);
   g_free (info->orig_text);
@@ -73,7 +73,7 @@ greeter_item_update_text (GreeterItemInfo *info)
       text = greeter_item_expand_text (info->orig_text);
 
       g_object_set (G_OBJECT (info->item),
-		    "text", text,
+		    "markup", text,
 		    NULL);
 
       g_free (text);
@@ -85,14 +85,20 @@ greeter_item_update_text (GreeterItemInfo *info)
 static char *
 get_clock (void)
 {
-  char str[256];
   struct tm *the_tm;
   time_t the_time;
 
   time (&the_time);
   the_tm = localtime (&the_time);
 
-  return ve_strftime (the_tm, _("%a %b %d, %I:%M %p"));
+  if (GdmUse24Clock) 
+    {
+      return ve_strftime (the_tm, _("%a %b %d, %H:%M"));
+    } 
+  else 
+    {
+      return ve_strftime (the_tm, _("%a %b %d, %I:%M %p"));
+    }
 }
 
 
@@ -101,9 +107,9 @@ greeter_item_expand_text (const char *text)
 {
   GString *str;
   const char *p;
-  const char *q;
   char *clock;
   int r;
+  gboolean underline = FALSE;
   char buf[256];
 
   str = g_string_sized_new (strlen (text));
@@ -121,14 +127,16 @@ greeter_item_expand_text (const char *text)
 	      g_string_append (str, "%");
 	      break;
 	    case 'h':
-	      r = gethostname (buf, sizeof(buf));
+	      buf[sizeof(buf) - 1] = '\0';
+	      r = gethostname (buf, sizeof(buf) - 1);
 	      if (r)
 		g_string_append (str, "localhost");
 	      else
 		g_string_append (str, buf);
 	      break;
 	    case 'o':
-	      r = getdomainname (buf, sizeof(buf));
+	      buf[sizeof(buf) - 1] = '\0';
+	      r = getdomainname (buf, sizeof(buf) - 1);
 	      if (r)
 		g_string_append (str, "localdomain");
 	      else
@@ -153,26 +161,27 @@ greeter_item_expand_text (const char *text)
 	    default:
 	      g_warning ("unknown escape code %%%c in text\n", *p);
 	    }
-	  p++;
+	}
+      else if (*p == '_')
+        {
+	  underline = TRUE;
+	  g_string_append (str, "<u>");
 	}
       else
 	{
-	  q = strchr(p, '%');
-	  if (q == NULL)
-	    {
-	      g_string_append (str, p);
-	      break;
-	    }
-	  else
-	    {
-	      g_string_append_len (str, p, q - p);
-	      p = q;
-	    }
+	  g_string_append_c (str, *p);
+	  if (underline)
+	    g_string_append (str, "</u>");
+	  underline = FALSE;
 	}
+      p++;
     }
   
  bail:
 
+  if (underline)
+    g_string_append (str, "</u>");
+
   return g_string_free (str, FALSE);
 }
 
